It provides:

    - opening molecular `.xyz` files
    - conversion between Cartesian and internal coordinate representations
    - molecular shape matching based on singular value decomposition
    - calculating atomic distances, bond angles and dihedral angles
    - calculating the principal moments of inertia
    - generating permuted geometries